def assert_(condition: object) -> None: ...

ERR_FRAGMENT: str

class DAVError(Exception):
    url: str | None
    reason: str
    def __init__(self, url: str | None = ..., reason: str | None = ...) -> None: ...

class AuthorizationError(DAVError): ...
class PropsetError(DAVError): ...
class ProppatchError(DAVError): ...
class PropfindError(DAVError): ...
class ReportError(DAVError): ...
class MkcolError(DAVError): ...
class MkcalendarError(DAVError): ...
class PutError(DAVError): ...
class DeleteError(DAVError): ...
class NotFoundError(DAVError): ...
class ConsistencyError(DAVError): ...
class ResponseError(DAVError): ...

exception_by_method: dict[str, type[DAVError]]
